%global with_debug 1

%if 0%{?with_debug}
%global _find_debuginfo_dwz_opts %{nil}
%global _dwz_low_mem_die_limit 0
%else
%global debug_package %{nil}
%endif

%if 0%{?fedora}
%define gobuild(o:) go build -buildmode pie -compiler gc -tags="rpm_crashtraceback ${BUILDTAGS:-}" -ldflags "${LDFLAGS:-} -B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \\n') -extldflags '%__global_ldflags'" -a -v -x %{?**};
%else
%if 0%{?rhel} > 7
%define gobuild(o:) go build -buildmode pie -compiler gc -tags="rpm_crashtraceback libtrust_openssl ${BUILDTAGS:-}" -ldflags "${LDFLAGS:-} -compressdwarf=false -B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \\n') -extldflags '%__global_ldflags'" -a -v -x %{?**};
%else
# Golang minor version
%define gominver 16
%define gobuild(o:) scl enable go-toolset-1.%{gominver} -- go build -buildmode pie -compiler gc -tags="rpm_crashtraceback libtrust_openssl ${BUILDTAGS:-}" -ldflags "${LDFLAGS:-} -compressdwarf=false -B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \\n') -extldflags '%__global_ldflags'" -a -v -x %{?**};
%endif
%endif

%global provider github
%global provider_tld com
%global project cri-o
%global repo cri-o
# https://github.com/cri-o/cri-o
%global import_path %{provider}.%{provider_tld}/%{project}/%{repo}
%global commit0 daab4d1d8431cf3af59855d3ad220e5ded5e5822
%global shortcommit0 %(c=%{commit0}; echo ${c:0:7})
%global git0 https://%{import_path}

%global service_name crio

Name: %{repo}
Version: 1.23.0
Release: 92.rhaos4.10.git%{shortcommit0}%{?dist}
Summary: Kubernetes Container Runtime Interface for OCI-based containers
License: ASL 2.0
URL: %{git0}
Source0: %{git0}/archive/%{commit0}/%{name}-%{shortcommit0}.tar.gz
Source1: seccomp.json
%if 0%{?rhel} && ! 0%{?fedora}
BuildRequires: go-toolset-1.%{gominver}
%else
BuildRequires: golang
%endif
BuildRequires: git
BuildRequires: glib2-devel
BuildRequires: glibc-static
BuildRequires: go-md2man
BuildRequires: gpgme-devel
BuildRequires: libassuan-devel
BuildRequires: libseccomp-devel
BuildRequires: make
BuildRequires: pkgconfig(systemd)
Requires(pre): container-selinux
Requires: skopeo-containers >= 1:0.1.40-1
Requires: runc >= 1.0.0-61.rc8
Obsoletes: ocid <= 0.3
Provides: ocid = %{version}-%{release}
Provides: %{service_name} = %{version}-%{release}
Requires: containernetworking-plugins >= 0.8.2-3
Requires: conmon >= 2.0.2-2

%description
%{summary}

%prep
%autosetup -Sgit -n %{name}-%{commit0}
sed -i 's/\.gopathok //' Makefile
sed -i 's/%{version}/%{version}-%{release}/' internal/version/version.go
sed -i 's/\/local//' contrib/systemd/%{service_name}.service
sed -i 's/\/local//' contrib/systemd/%{service_name}-wipe.service

%build
mkdir _output
pushd _output
mkdir -p src/%{provider}.%{provider_tld}/{%{project},opencontainers}
ln -s $(dirs +1 -l) src/%{import_path}
popd

ln -s vendor src
export GOPATH=$(pwd)/_output:$(pwd)
export BUILDTAGS="selinux seccomp exclude_graphdriver_devicemapper exclude_graphdriver_btrfs containers_image_ostree_stub"
export GO111MODULE=off
# https://bugzilla.redhat.com/show_bug.cgi?id=1825623
export VERSION=%{version}
# build crio
%gobuild -o bin/%{service_name} %{import_path}/cmd/%{service_name}

# build crio-status
%gobuild -o bin/crio-status %{import_path}/cmd/crio-status

# build pinns and docs
%{__make} bin/pinns
%if 0%{?rhel} <= 7 && ! 0%{?fedora}
GO_MD2MAN=go-md2man GO="scl enable go-toolset-1.%{gominver} -- go" %{__make} docs
%else
GO_MD2MAN=go-md2man %{__make} docs
%endif

%install
./bin/%{service_name} \
      --selinux \
      --cgroup-manager "systemd" \
      --cni-plugin-dir "%{_libexecdir}/cni" \
      --metrics-port 9537 \
      --enable-metrics \
      config > %{service_name}.conf

# install conf files
install -dp %{buildroot}%{_sysconfdir}/cni/net.d
install -p -m 644 contrib/cni/10-crio-bridge.conf %{buildroot}%{_sysconfdir}/cni/net.d/100-crio-bridge.conf
install -p -m 644 contrib/cni/99-loopback.conf %{buildroot}%{_sysconfdir}/cni/net.d/200-loopback.conf
make PREFIX=%{buildroot}%{_prefix} DESTDIR=%{buildroot} \
            install.bin-nobuild \
            install.completions \
            install.config-nobuild \
            install.man-nobuild \
            install.systemd

# install seccomp.json
install -p -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/%{service_name}/seccomp.json
install -dp %{buildroot}%{_sharedstatedir}/containers
install -dp %{buildroot}%{_sharedstatedir}/cni/bin
install -dp %{buildroot}%{_sysconfdir}/kubernetes/cni/net.d
install -dp %{buildroot}%{_datadir}/containers/oci/hooks.d
install -dp %{buildroot}/opt/cni/bin

%check
%if 0%{?with_check}
export GOPATH=%{buildroot}/%{gopath}:$(pwd)/Godeps/_workspace:%{gopath}
%endif

%post
%systemd_post %{service_name}

%preun
%systemd_preun %{service_name}

%postun
%systemd_postun_with_restart %{service_name}

#define license tag if not already defined
%{!?_licensedir:%global license %doc}

%files
%license LICENSE
%doc README.md
%{_bindir}/%{service_name}
%{_bindir}/%{service_name}-status
%{_bindir}/pinns
%{_mandir}/man5/%{service_name}.conf*5*
%{_mandir}/man8/%{service_name}*.8*
%dir %{_sysconfdir}/%{service_name}
%config(noreplace) %{_sysconfdir}/%{service_name}/%{service_name}.conf
%config(noreplace) %{_sysconfdir}/%{service_name}/seccomp.json
%config(noreplace) %{_sysconfdir}/cni/net.d/100-%{service_name}-bridge.conf
%config(noreplace) %{_sysconfdir}/cni/net.d/200-loopback.conf
%config(noreplace) %{_sysconfdir}/crictl.yaml
%{_unitdir}/%{service_name}.service
%{_unitdir}/%{service_name}-wipe.service
%dir %{_sharedstatedir}/containers
%dir %{_sharedstatedir}/cni
%dir %{_sharedstatedir}/cni/bin
%dir %{_sysconfdir}/kubernetes
%dir %{_sysconfdir}/kubernetes/cni
%dir %{_sysconfdir}/kubernetes/cni/net.d
%dir %{_datadir}/containers
%dir %{_datadir}/containers/oci
%dir %{_datadir}/containers/oci/hooks.d
%dir /opt/cni
%dir /opt/cni/bin
%dir %{_datadir}/oci-umount
%dir %{_datadir}/oci-umount/oci-umount.d
%{_datadir}/oci-umount/oci-umount.d/%{service_name}-umount.conf
%{_datadir}/bash-completion/completions/%{service_name}*
%{_datadir}/fish/completions/%{service_name}*.fish
%{_datadir}/zsh/site-functions/_%{service_name}*

%changelog
* Tue Dec 14 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-92.rhaos4.10.gitdaab4d1
- autobuilt daab4d1

* Mon Dec 13 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-91.rhaos4.10.gitfc844e4
- autobuilt fc844e4

* Mon Dec 06 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-90.rhaos4.10.gitd57d291
- autobuilt d57d291

* Fri Dec 03 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-89.rhaos4.10.git367232b
- autobuilt 367232b

* Thu Dec 02 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-88.rhaos4.10.git336a2eb
- autobuilt 336a2eb

* Mon Nov 29 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-87.rhaos4.10.git1e2f62a
- autobuilt 1e2f62a

* Mon Nov 29 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-86.rhaos4.10.git3bfface
- autobuilt 3bfface

* Mon Nov 29 2021 Peter Hunt <pehunt@redhat.com> - 1.23.0-85.rhaos4.10.git7048f24
- bump version number

* Sat Nov 27 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-31.rhaos4.10.git7048f24
- bump to 1.23.0
- autobuilt 7048f24

* Tue Nov 23 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-30.rhaos4.10.git7048f24
- autobuilt 7048f24

* Tue Nov 23 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-29.rhaos4.10.git036030d
- autobuilt 036030d

* Tue Nov 23 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-28.rhaos4.10.git8deefdd
- autobuilt 8deefdd

* Tue Nov 23 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-27.rhaos4.10.git31faba4
- autobuilt 31faba4

* Fri Nov 19 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-26.rhaos4.10.git2874194
- autobuilt 2874194

* Fri Nov 19 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-25.rhaos4.10.gitacc36e5
- autobuilt acc36e5

* Thu Nov 18 2021 Peter Hunt <pehunt@redhat.com> - 1.23.0-24.rhaos4.10.git407d866
- install crio.conf, but without storage opts

* Tue Nov 16 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-23.rhaos4.10.git407d866
- autobuilt 407d866

* Mon Nov 15 2021 Peter Hunt <pehunt@redhat.com> - 1.23.0-22.rhaos4.10.gite2c9990
- fix crio conf removal

* Mon Nov 15 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-21.rhaos4.10.gite2c9990
- autobuilt e2c9990

* Mon Nov 15 2021 Peter Hunt <pehunt@redhat.com> - 1.23.0-20.rhaos4.10.git10a09d7
- fix seccomp source

* Thu Nov 11 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-1.rhaos4.10.git7048f249.rhaos4.10.git10a09d7
- autobuilt 10a09d7

* Thu Nov 11 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-1.rhaos4.10.git7048f248.rhaos4.10.git518dd42
- autobuilt 518dd42

* Tue Nov 09 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-1.rhaos4.10.git7048f247.rhaos4.10.git529276d
- autobuilt 529276d

* Tue Nov 09 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-1.rhaos4.10.git7048f246.rhaos4.10.gitf9a1123
- autobuilt f9a1123

* Tue Nov 09 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-1.rhaos4.10.git7048f245.rhaos4.10.git143babd
- autobuilt 143babd

* Mon Nov 08 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-1.rhaos4.10.git7048f244.rhaos4.10.gite93843f
- autobuilt e93843f

* Mon Nov 08 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-1.rhaos4.10.git7048f243.rhaos4.10.git181a780
- autobuilt 181a780

* Thu Nov 04 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-1.rhaos4.10.git7048f242.rhaos4.10.git3943334
- autobuilt 3943334

* Wed Nov 03 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-1.rhaos4.10.git7048f241.rhaos4.10.gitd690832
- autobuilt d690832

* Tue Nov 02 2021 Peter Hunt <pehunt@redhat.com> - 1.23.0-1.rhaos4.10.git7048f240.rhaos4.10.gitb5002c4
- bump to b5002c42fb2fab5daed0a68576c06dd9c0116f86

* Thu Oct 28 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-9.rhaos4.10.git0fb9c0c
- autobuilt 0fb9c0c

* Wed Oct 27 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-8.rhaos4.10.git2e9a711
- autobuilt 2e9a711

* Tue Oct 26 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-7.rhaos4.10.gitb026482
- autobuilt b026482

* Tue Oct 26 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-6.rhaos4.10.gitf51497f
- autobuilt f51497f

* Mon Oct 25 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-5.rhaos4.10.gitbf8bc04
- autobuilt bf8bc04

* Mon Oct 25 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-4.rhaos4.10.gite90307f
- autobuilt e90307f

* Thu Oct 21 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-3.rhaos4.10.gitfd336b5
- autobuilt fd336b5

* Thu Oct 21 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.23.0-2.rhaos4.10.gitcf735cf
- bump to 1.23.0
- autobuilt cf735cf

* Wed Oct 20 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-6.rhaos4.10.git6548676
- autobuilt 6548676

* Wed Oct 20 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-5.rhaos4.10.gitc22219b
- autobuilt c22219b

* Wed Oct 20 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-4.rhaos4.10.git22986bd
- autobuilt 22986bd

* Wed Oct 20 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-3.rhaos4.10.git8a6b305
- autobuilt 8a6b305

* Tue Oct 19 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-2.rhaos4.10.git7163dbb
- bump to 1.22.0
- autobuilt 7163dbb

* Mon Oct 18 2021 Peter Hunt <pehunt@redhat.com> - 1.23.0-84.rhaos4.10.gitb393084
- bump verison number

* Fri Oct 08 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-83.rhaos4.10.gitb393084
- autobuilt b393084

* Thu Sep 23 2021 Peter Hunt <pehunt@redhat.com> - 1.22.0-82.rhaos4.10.git6becad2
- bump rhcos version

* Wed Aug 25 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-81.rhaos4.9.git6becad2
- autobuilt 6becad2

* Tue Aug 24 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-80.rhaos4.9.git5d5a754
- autobuilt 5d5a754

* Tue Aug 24 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-79.rhaos4.9.git3682514
- autobuilt 3682514

* Tue Aug 24 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-78.rhaos4.9.git1d44719
- autobuilt 1d44719

* Tue Aug 24 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-77.rhaos4.9.git690c533
- autobuilt 690c533

* Tue Aug 24 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-76.rhaos4.9.gitcf0a31c
- autobuilt cf0a31c

* Tue Aug 24 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-75.rhaos4.9.git10db266
- autobuilt 10db266

* Tue Aug 24 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-74.rhaos4.9.gite3ee92e
- autobuilt e3ee92e

* Mon Aug 23 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-73.rhaos4.9.git4e5a828
- autobuilt 4e5a828

* Mon Aug 23 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-72.rhaos4.9.git411113d
- autobuilt 411113d

* Mon Aug 23 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-71.rhaos4.9.git9f38eee
- autobuilt 9f38eee

* Sat Aug 21 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-70.rhaos4.9.git177ed5f
- autobuilt 177ed5f

* Sat Aug 21 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-69.rhaos4.9.git8234f90
- autobuilt 8234f90

* Fri Aug 20 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-68.rhaos4.9.git2d289a2
- autobuilt 2d289a2

* Fri Aug 20 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-67.rhaos4.9.git1520733
- autobuilt 1520733

* Fri Aug 20 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-66.rhaos4.9.gitf05d651
- autobuilt f05d651

* Thu Aug 19 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-65.rhaos4.9.gitd8af189
- autobuilt d8af189

* Thu Aug 19 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-64.rhaos4.9.git1536782
- autobuilt 1536782

* Thu Aug 19 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-63.rhaos4.9.gitabbfb13
- autobuilt abbfb13

* Thu Aug 19 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-62.rhaos4.9.gita6ed448
- autobuilt a6ed448

* Thu Aug 19 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-61.rhaos4.9.git359c7f8
- autobuilt 359c7f8

* Thu Aug 19 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-60.rhaos4.9.git3a523e9
- autobuilt 3a523e9

* Wed Aug 18 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-59.rhaos4.9.gitc1e95b1
- autobuilt c1e95b1

* Wed Aug 18 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-58.rhaos4.9.git56fb46e
- autobuilt 56fb46e

* Wed Aug 18 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-57.rhaos4.9.gitdf41b98
- autobuilt df41b98

* Wed Aug 18 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-56.rhaos4.9.git71ab700
- autobuilt 71ab700

* Wed Aug 18 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-55.rhaos4.9.git8bcf6f7
- autobuilt 8bcf6f7

* Tue Aug 17 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-54.rhaos4.9.git71ec863
- autobuilt 71ec863

* Tue Aug 17 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-53.rhaos4.9.git94060e3
- autobuilt 94060e3

* Tue Aug 17 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-52.rhaos4.9.gitfe3d631
- autobuilt fe3d631

* Tue Aug 17 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-51.rhaos4.9.git7cc1f62
- autobuilt 7cc1f62

* Mon Aug 16 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-50.rhaos4.9.gitc53e78f
- autobuilt c53e78f

* Wed Aug 11 2021 Peter Hunt <pehunt@redhat.com> - 1.22.0-49.rhaos4.9.git78f06f2
- use conmon from path

* Tue Aug 10 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-48.rhaos4.9.git78f06f2
- autobuilt 78f06f2

* Mon Aug 09 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-47.rhaos4.9.gita07f02f
- autobuilt a07f02f

* Mon Aug 09 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-46.rhaos4.9.giteb3cca9
- autobuilt eb3cca9

* Mon Aug 09 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-45.rhaos4.9.git779df95
- autobuilt 779df95

* Sun Aug 08 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-44.rhaos4.9.git6092081
- autobuilt 6092081

* Fri Aug 06 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-43.rhaos4.9.git126b893
- autobuilt 126b893

* Thu Aug 05 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-42.rhaos4.9.git2c92506
- autobuilt 2c92506

* Thu Aug 05 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-41.rhaos4.9.git226e658
- autobuilt 226e658

* Wed Aug 04 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-40.rhaos4.9.gitcc72388
- autobuilt cc72388

* Wed Aug 04 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-39.rhaos4.9.git8d4df4e
- autobuilt 8d4df4e

* Tue Aug 03 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-38.rhaos4.9.gita414fed
- autobuilt a414fed

* Mon Aug 02 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-37.rhaos4.9.git79a25c4
- autobuilt 79a25c4

* Mon Aug 02 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-36.rhaos4.9.gitee8e721
- autobuilt ee8e721

* Fri Jul 30 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-35.rhaos4.9.git1b8b9e4
- autobuilt 1b8b9e4

* Thu Jul 29 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-34.rhaos4.9.git6ac8cee
- autobuilt 6ac8cee

* Wed Jul 28 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-33.rhaos4.9.git13e698f
- autobuilt 13e698f

* Wed Jul 28 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-32.rhaos4.9.gitb6d6cde
- autobuilt b6d6cde

* Tue Jul 27 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-31.rhaos4.9.git5ab85f5
- autobuilt 5ab85f5

* Mon Jul 26 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-30.rhaos4.9.gita212a95
- autobuilt a212a95

* Mon Jul 26 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-29.rhaos4.9.git4fa3dd3
- autobuilt 4fa3dd3

* Mon Jul 26 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-28.rhaos4.9.git49a8247
- autobuilt 49a8247

* Fri Jul 23 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-27.rhaos4.9.git0fc6d47
- autobuilt 0fc6d47

* Fri Jul 23 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-26.rhaos4.9.git0f8266d
- autobuilt 0f8266d

* Wed Jul 21 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-25.rhaos4.9.gite06cce2
- autobuilt e06cce2

* Tue Jul 20 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-24.rhaos4.9.gitaf2035b
- autobuilt af2035b

* Mon Jul 19 2021 Peter Hunt <pehunt@redhat.com> - 1.22.0-23.rhaos4.9.git1cf63c7
- sunset support for custom rpm crio.service file

* Mon Jul 19 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-7.rhaos4.9.git1cf63c7
- autobuilt 1cf63c7

* Sat Jul 17 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-21.rhaos4.9.git635b2d9
- autobuilt 635b2d9

* Sat Jul 17 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-20.rhaos4.9.gite00180d
- autobuilt e00180d

* Fri Jul 16 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-1.rhaos4.10.git7163dbb9.rhaos4.9.gitc969a38
- autobuilt c969a38

* Fri Jul 16 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-1.rhaos4.10.git7163dbb8.rhaos4.9.gitcd1c5a0
- autobuilt cd1c5a0

* Fri Jul 16 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-1.rhaos4.10.git7163dbb7.rhaos4.9.git1309dd2
- autobuilt 1309dd2

* Thu Jul 15 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-1.rhaos4.10.git7163dbb6.rhaos4.9.git4d14fd6
- autobuilt 4d14fd6

* Thu Jul 15 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-1.rhaos4.10.git7163dbb5.rhaos4.9.gitde5e0fe
- autobuilt de5e0fe

* Wed Jul 14 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-1.rhaos4.10.git7163dbb4.rhaos4.9.gitf2dcf32
- autobuilt f2dcf32

* Wed Jul 14 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-1.rhaos4.10.git7163dbb3.rhaos4.9.gitacd0f73
- autobuilt acd0f73

* Wed Jul 14 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-1.rhaos4.10.git7163dbb2.rhaos4.9.gitb123b0c
- autobuilt b123b0c

* Wed Jul 14 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-1.rhaos4.10.git7163dbb1.rhaos4.9.gitab3a2f4
- autobuilt ab3a2f4

* Tue Jul 13 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-1.rhaos4.10.git7163dbb0.rhaos4.9.git196e779
- autobuilt 196e779

* Thu Jul 08 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-9.rhaos4.9.giteffa584
- autobuilt effa584

* Thu Jul 08 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-8.rhaos4.9.git472b3ae
- autobuilt 472b3ae

* Thu Jul 08 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-7.rhaos4.9.gitfeb7a4c
- autobuilt feb7a4c

* Wed Jul 07 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-6.rhaos4.9.git3e5a1e4
- autobuilt 3e5a1e4

* Mon Jul 05 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-5.rhaos4.9.gitc8b82d6
- autobuilt c8b82d6

* Sat Jul 03 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-4.rhaos4.9.gitd41627b
- autobuilt d41627b

* Thu Jul 01 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-3.rhaos4.9.git0aa5724
- autobuilt 0aa5724

* Thu Jul 01 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.22.0-2.rhaos4.9.git2b8e727
- bump to 1.22.0
- autobuilt 2b8e727

* Wed Jun 30 2021 Peter Hunt <pehunt@redhat.com> - 1.21.0-5.rhaos4.9.git741bd7c
- rebuild for golang fips fix

* Wed Jun 30 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-4.rhaos4.9.git741bd7c
- autobuilt 741bd7c

* Wed Jun 30 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-3.rhaos4.9.git6664604
- autobuilt 6664604

* Tue Jun 29 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-2.rhaos4.9.git9dd6f42
- bump to 1.21.0
- autobuilt 9dd6f42

* Tue Jun 29 2021 Peter Hunt <pehunt@redhat.com> - 1.22.0-1.rhaos4.10.git7163dbb.rhaos4.9.git2b8e727.rhaos4.9.gitcd7f051
- Initial build of 1.22
